# Auth With Guards
Example of Ellar Authentication and Authorization with Authentication Handler and Authorization Interceptors

## Requirements
Python >= 3.7
Poetry

## Project setup
```
poetry install
```

### Development Server
```
ellar runserver --reload
```

### Page
visit [http://127.0.0.1:8000/docs/](http://127.0.0.1:8000/docs/)
